@@ -88,7 +88,7 @@ class Appliance:  # pylint: disable=too-many-public-methods
     @classmethod
     def daikin_values(cls, dimension):
         """Return sorted list of translated values."""
-        return sorted(list(cls.TRANSLATIONS[dimension].values()))
+        return sorted(list(cls.TRANSLATIONS.get(dimension, {}).values()))
 
     @staticmethod
     async def factory(device_id, session=None, **kwargs):
@@ -175,7 +175,8 @@ class Appliance:  # pylint: disable=too-many-public-methods
 
     async def init(self):
         """Init status."""
-        await self.update_status()
+        # Re-defined in all sub-classes
+        raise NotImplementedError
 
     async def _get_resource(self, resource, retries=3):
         """Update resource."""
@@ -219,19 +220,16 @@ class Appliance:  # pylint: disable=too-many-public-methods
                 today=self.energy_consumption(mode=mode, time=TIME_TODAY),
                 yesterday=self.energy_consumption(mode=mode, time=TIME_YESTERDAY),
             )
+            if new_state.today is None:
+                continue
 
             if self._energy_consumption_history[mode]:
                 old_state = self._energy_consumption_history[mode][0]
-            else:
-                old_state = EnergyConsumptionState(None, None, None)
 
-            if old_state.today is not None and new_state.today == old_state.today:
-                if (
-                    old_state.yesterday is not None
-                    and new_state.yesterday == old_state.yesterday
-                ):
-                    # State has not changed, nothing to register
-                    continue
+                if new_state.today == old_state.today:
+                    if new_state.yesterday == old_state.yesterday:
+                        # State has not changed, nothing to register
+                        continue
 
             self._energy_consumption_history[mode].insert(0, new_state)
 
@@ -402,6 +400,11 @@ class Appliance:  # pylint: disable=too-many-public-methods
             if curr.today > prev.today:
                 # Normal behavior, today state is growing
                 energy += curr.today - prev.today
+            elif curr.yesterday is None:
+                _LOGGER.error(
+                    f'Decreasing today state and missing yesterday state caused an impossible energy consumption measure of {mode}'
+                )
+                return None
             elif curr.yesterday >= prev.today:
                 # If today state is not growing (or even declines), we probably have shifted 1 day
                 # Thus we should have yesterday state greater or equal to previous today state
@@ -409,7 +412,7 @@ class Appliance:  # pylint: disable=too-many-public-methods
                 energy += curr.yesterday - prev.today
                 energy += curr.today
             else:
-                _LOGGER.error('Impossible energy consumption measure')
+                _LOGGER.error(f'Impossible energy consumption measure of {mode}')
                 return None
             if early_break:
                 break
